@@ -53,7 +53,10 @@ try:
     from urllib.parse import urlencode
 except ImportError:
     from urllib import urlencode
-import xml.etree.cElementTree as ET
+try:
+    import xml.etree.cElementTree as ET
+except ImportError:
+    import xml.etree.ElementTree as ET
 
 from lazr.uri import URI, merge
 
@@ -877,8 +880,9 @@ class RepresentationDefinition(WADLResolvableDefinition, HasParametersMixin):
                     raise TypeError('bytes payload expected: %s' % type(value))
                 buf.write(value)
             else:
-                if not isinstance(value, str):
-                    raise TypeError('str payload expected: %s' % type(value))
+                if not isinstance(value, _string_types):
+                    raise TypeError(
+                        'string payload expected: %s' % type(value))
                 lines = re.split(r'\r\n|\r|\n', value)
                 for line in lines[:-1]:
                     buf.write(line.encode('UTF-8'))
